Package: ghclass
Title: Tools for Managing Classes on GitHub
Version: 0.4.1
Authors@R: 
    c(person(given = "Colin",
             family = "Rundel",
             role = c("aut", "cre"),
             email = "rundel@gmail.com"),
      person(given = "Mine",
             family = "Cetinkaya-Rundel",
             role = "aut",
             email = "mine@rstudio.com"),
      person(given = "Therese",
             family = "Anders",
             role = "ctb",
             email = "tanders@usc.edu"))
Description: Interface for the GitHub API that enables efficient 
    management of courses on GitHub. It has a functionality for 
    managing organizations, teams, repositories, and users on GitHub 
    and helps automate most of the tedious and repetitive tasks 
    around creating and distributing assignments.
License: GPL-3
URL: https://github.com/rundel/ghclass,
        https://rundel.github.io/ghclass/
BugReports: https://github.com/rundel/ghclass/issues
Depends: R (>= 3.4.0)
Imports: base64enc, fs, gh (>= 1.4.0), glue, httr, lubridate, purrr,
        rlang, stringr, tibble, whisker, withr, dplyr, cli (>= 3.0.0),
        lifecycle, readr, tidyselect
Suggests: here, knitr, rmarkdown, sodium, styler, testthat (>= 3.0.0),
        usethis, gert, gitcreds
Encoding: UTF-8
Config/roxygen2/version: 8.0.0
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-07-25 23:08:29 UTC; rundel
Author: Colin Rundel [aut, cre],
  Mine Cetinkaya-Rundel [aut],
  Therese Anders [ctb]
Maintainer: Colin Rundel <rundel@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-25 23:20:02 UTC
