# Generated by roxygen2: do not edit by hand

S3method(filter_results,data.frame)
S3method(filter_results,default)
export(action_add_badge)
export(action_artifact_delete)
export(action_artifact_download)
export(action_artifacts)
export(action_remove_badge)
export(action_run_logs)
export(action_runs)
export(action_runtime)
export(action_status)
export(action_workflows)
export(arg_is_chr)
export(arg_is_chr_scalar)
export(arg_is_lgl)
export(arg_is_lgl_scalar)
export(arg_is_pos_int)
export(arg_is_pos_int_scalar)
export(branch_create)
export(branch_delete)
export(branch_remove)
export(cli_glue)
export(cli_stop)
export(cli_warn)
export(error)
export(failed)
export(format_repo)
export(get_repo_name)
export(get_repo_owner)
export(ghclass_api_v3_req)
export(github_api_repo_get_file)
export(github_api_repo_tree)
export(github_get_api_limit)
export(github_get_max_rate)
export(github_get_max_wait)
export(github_get_token)
export(github_graphql_rate_limit)
export(github_orgs)
export(github_rate_limit)
export(github_reset_token)
export(github_set_api_limit)
export(github_set_max_rate)
export(github_set_max_wait)
export(github_set_token)
export(github_test_token)
export(github_token_scopes)
export(github_whoami)
export(issue_close)
export(issue_create)
export(issue_edit)
export(local_pat)
export(local_repo_add)
export(local_repo_anonymize)
export(local_repo_branch)
export(local_repo_clone)
export(local_repo_commit)
export(local_repo_log)
export(local_repo_pull)
export(local_repo_push)
export(local_repo_rename)
export(match_repo)
export(org_admins)
export(org_allows_forking)
export(org_create_assignment)
export(org_exists)
export(org_grade_assignment)
export(org_invite)
export(org_members)
export(org_pending)
export(org_remove)
export(org_repo_forking)
export(org_repo_search)
export(org_repo_stats)
export(org_repos)
export(org_set_repo_permission)
export(org_set_workflow_permissions)
export(org_sitrep)
export(org_team_details)
export(org_teams)
export(org_user_repos)
export(org_workflow_permissions)
export(pages_create)
export(pages_delete)
export(pages_enabled)
export(pages_status)
export(pr_create)
export(read_bin_file)
export(repo_add_file)
export(repo_add_team)
export(repo_add_user)
export(repo_allows_forking)
export(repo_branches)
export(repo_clone)
export(repo_clone_url)
export(repo_collaborators)
export(repo_commits)
export(repo_contributors)
export(repo_create)
export(repo_delete)
export(repo_delete_file)
export(repo_exists)
export(repo_files)
export(repo_get_file)
export(repo_get_readme)
export(repo_ignore)
export(repo_is_template)
export(repo_issues)
export(repo_ls)
export(repo_mirror)
export(repo_mirror_template)
export(repo_modify_file)
export(repo_n_commits)
export(repo_prs)
export(repo_pushes)
export(repo_put_file)
export(repo_remove_team)
export(repo_remove_user)
export(repo_rename)
export(repo_set_forking)
export(repo_set_template)
export(repo_style)
export(repo_team_permission)
export(repo_unwatch)
export(repo_user_permission)
export(repo_watch)
export(repo_watching)
export(result)
export(status_msg)
export(succeeded)
export(team_create)
export(team_delete)
export(team_invite)
export(team_members)
export(team_pending)
export(team_remove)
export(team_rename)
export(team_repos)
export(team_roster)
export(user_exists)
export(user_repos)
export(user_type)
export(with_pat)
importFrom(dplyr,"%>%")
importFrom(rlang,".data")
