#' Internal ghclass helpers
#'
#' These functions are exported so that companion packages (e.g.
#' ghclasspeer) can reuse them. They are not intended for end users
#' and their interfaces may change without notice.
#'
#' @keywords internal
#' @name ghclass-internal
NULL
