---
title: "Author rating form"
output: github_document
params:
  helpfulness: [INSERT SCORE]
  accuracy: [INSERT SCORE]
  fairness: [INSERT SCORE]
---


## Instructions

Please rate the reviewer's feedback based on the categories below on a scale from "Strongly disagree" to "Strongly agree." Please replace `[INSERT SCORE]` in the `helpfulness`, `accuracy`, and `fairness` fields in the YAML with the scores you give the reviewer for each category.

1. `helpfulness`: "The reviewer's feedback was constructive and helpful."  [max. 4 points]

2. `accuracy`: "The reviewer's assessment accurately describes the quality of my work." [max. 4 points]

3. `fairness`: "The reviewer's assessment was fair." [max. 4 points]

| Score | Rating            |
|-------|-------------------|
| 1     | Strongly disagree |
| 2     | Disagree          |
| 3     | Agree             |
| 4     | Strongly agree    |


You can use the check boxes to help you keep track of your progress.
